@@ -1,5 +1,5 @@
 
-/* SVN-ID:      $Id: wxactivex.cpp 2355 2008-04-07 07:03:52Z mdootson $ */
+/* SVN-ID:      $Id: wxactivex.cpp 2364 2008-04-10 04:21:35Z mdootson $ */
 
 /*
                 wxActiveX Library Licence, Version 3
@@ -1393,6 +1393,12 @@ wxString wxActiveX::GetMethodArgName(int idx , int argx) {
      return( param.name ) ;
 }
 
+void wxActiveX::ActivateOLEWindowDirect(bool activate)
+{
+    if (m_oleInPlaceActiveObject.Ok())
+        m_oleInPlaceActiveObject->OnFrameWindowActivate(activate);
+}
+
 ///////////////////////////////////////////////
 // Type Info exposure
 const wxActiveX::FuncX& wxActiveX::GetEventDesc(int idx) const
